clear all

% INFORMATION FOR CROSS SECTION
lat1 = 48.5;
lat2 = 40.5;   %STARTING AND ENDING LATITUDES
lon1 = -117;
lon2 = -105;   %STARTING AND ENDING LONGITUDES
dep =  1000;    %DEPTH EXTENT

cax=1.2;       %COLOR AXIS

% LOAD MIT MODEL
load MITP_USA_2008DEC
dV = MITP_USA_2008DEC;
figure;

LON = unique(dV(:,1))'*pi/180;
LAT = pi/2-unique(dV(:,2))'*pi/180;
R = 6371-(25:25:1000);

[lon lat r]=meshgrid(LON,LAT,R);

map = reshape(dV(:,3:end),[],1);
map = reshape(map,[length(LAT),length(LON),length(R)]);

lat1=(90-lat1)*pi/180; lat2=(90-lat2)*pi/180;
lon1=lon1*pi/180; lon2=lon2*pi/180;

NX = 300;   %Number of steps in interpolation

lats=linspace(lat1,lat2,NX);
lons=linspace(lon1,lon2,NX);
deps=linspace(6371,6371-dep,NX);

[xd yd]=meshgrid(lons,lats);
yd=yd';
zd = deps'*ones(1,NX);


slc=interp3(lon,lat,r,map,xd,yd,zd);

xs=cos(xd).*sin(yd).*zd;
ys=sin(xd).*sin(yd).*zd;
zs=cos(yd).*zd;

d=acos(sin(pi/2-lat1).*sin(pi/2-lat2)+cos(pi/2-lat1).*cos(pi/2-lat2).*cos(lon1-lon2))/2;
dd=ones(NX,1)*linspace(-d,d,NX);


surf(sin(dd).*zd,cos(dd).*zd,zeros(NX,NX),slc,'Linestyle','none')
grid off;axis off
view([0,90]);caxis([-cax,cax]);
hold on
lw=2;
plot(sin(linspace(-d,d,NX))*(6371-410),cos(linspace(-d,d,NX))*(6371-410),'k','Linestyle','--','Linewidth',lw)
plot(sin(linspace(-d,d,NX))*(6371-660),cos(linspace(-d,d,NX))*(6371-660),'k','Linestyle','--','Linewidth',lw)
plot(sin(linspace(-d,d,NX))*(6371-dep),cos(linspace(-d,d,NX))*(6371-dep),'k','Linewidth',lw)
plot(sin(linspace(-d,d,NX))*(6371),cos(linspace(-d,d,NX))*(6371),'k','Linewidth',lw)
plot(sin(-d)*linspace(6371-dep,6371,NX),cos(-d)*linspace(6371-dep,6371,NX),'k','Linewidth',lw)
plot(sin(d)*linspace(6371-dep,6371,NX),cos(d)*linspace(6371-dep,6371,NX),'k','Linewidth',lw)
text(sin(-d)*6400,cos(-d)*6400,'A','FontSize',16,'FontWeight','bold','HorizontalAlignment','center')
text(sin(d)*6400,cos(d)*6400,'B','FontSize',16,'FontWeight','bold','HorizontalAlignment','center')
text(0,6340-410,[num2str(410) 'km'],'FontSize',12,'HorizontalAlignment','center')
text(0,6340-660,[num2str(660) 'km'],'FontSize',12,'HorizontalAlignment','center')
text(0,6340-dep,[num2str(dep) 'km'],'FontSize',12,'HorizontalAlignment','center')
axis equal;axis tight;
title(['P-wave perturbation'])
colormap(fliplr(jet));colorbar('Location','SouthOutside');

% MAP SECTION PLOTTING AREA
figure;
mapdep = 100;    %DEPTH OF MAP SECTION
maxlat=55;        
minlat=25;
maxlon=-90;
minlon=-130;     %DIMENSIONS OF MAP SECTION
cax = 1.5;       %MAP COLOR AXIS

NX=300;
latz=linspace(minlat,maxlat,NX);
lonz=linspace(minlon,maxlon,NX);
zd=ones(NX)*(6371-mapdep);
[xd yd]=meshgrid(lonz,latz);
slc=interp3(lon*180/pi,90-lat*180/pi,r,map,xd,yd,zd);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% LOAD COASTLINE AND STATE DATA
load coastdata
plot(coastdata(:,1),coastdata(:,2),'k')  %Plot coast data
%states = shaperead('usastatehi', 'UseGeoCoords', true);
%for i = 1:50; plot( states(i).Lon,states(i).Lat,'k','LineWidth',1); hold on;end
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

hold on
xlim([minlon maxlon]);ylim([minlat maxlat]);axis square
title(['P-wave perturbation at ' num2str(mapdep) ' km depth'])
xlabel('Longitude');ylabel('Latitude');
colormap(fliplr(jet));colorbar('Location','EastOutside');

plot(lons*180/pi,90-lats*180/pi,'w','LineWidth',2);
text(lons(1)*180/pi,90-lats(1)*180/pi,'A','Color','w','FontSize',16,'FontWeight','bold','HorizontalAlignment','center')
text(lons(end)*180/pi,90-lats(end)*180/pi,'B','Color','w','FontSize',16,'FontWeight','bold','HorizontalAlignment','center')
surf(lonz,latz,-ones(NX),slc,'Linestyle','none');view([0 90]);caxis([-cax,cax])


